@@ -381,7 +381,7 @@ if (isset($_POST["delete"]) === TRUE) {
 }
 
 /* ɽ */
-$mod_data = "";
+$mod_data = array();
 if (isset($_POST["domname"]) === TRUE) {
     $key_domain = $_POST["domname"];
 }
